@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-23'; # DATE
+our $DATE = '2022-07-24'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.043'; # VERSION
+our $VERSION = '0.044'; # VERSION
 
 use Regexp::Pattern::Perl::Module ();
 
@@ -125,7 +125,7 @@ Sah::Schema::perl::modname_with_optional_args - Perl module name (e.g. Foo::Bar)
 
 =head1 VERSION
 
-This document describes version 0.043 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2022-07-23.
+This document describes version 0.044 of Sah::Schema::perl::modname_with_optional_args (from Perl distribution Sah-Schemas-Perl), released on 2022-07-24.
 
 =head1 SYNOPSIS
 
@@ -173,8 +173,8 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = ["Foo",["arg1","arg2"],{}];
- my $errmsg = $validator->($data); # => "Length must be at most 2"
+ $data = ["Foo Bar"];
+ my $errmsg = $validator->($data); # => "\@[0]: Must match regex pattern \\A(?:[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*)\\z"
 
 Often a schema has coercion rule or default value, so after validation the
 validated value is different. To return the validated (set-as-default, coerced,
@@ -188,8 +188,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["",["Foo",{arg1=>1,arg2=>2}]]
  
  # a sample invalid data
- $data = ["Foo",["arg1","arg2"],{}];
- my $res = $validator->($data); # => ["Length must be at most 2",["Foo",["arg1","arg2"],{}]]
+ $data = ["Foo Bar"];
+ my $res = $validator->($data); # => ["\@[0]: Must match regex pattern \\A(?:[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*)\\z",["Foo Bar"]]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
