@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-23'; # DATE
+our $DATE = '2022-07-24'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.043'; # VERSION
+our $VERSION = '0.044'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module prefix, e.g. Foo::Bar::',
@@ -64,7 +64,7 @@ Sah::Schema::perl::modprefix - Perl module prefix, e.g. Foo::Bar::
 
 =head1 VERSION
 
-This document describes version 0.043 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2022-07-23.
+This document describes version 0.044 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2022-07-24.
 
 =head1 SYNOPSIS
 
@@ -104,7 +104,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "Foo::Bar::";
+ $data = "Foo-";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -119,8 +119,8 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "Foo::Bar::";
- my $res = $validator->($data); # => ["","Foo::Bar::"]
+ $data = "Foo-";
+ my $res = $validator->($data); # => ["","Foo::"]
  
  # a sample invalid data
  $data = "::Foo";
